@@ -30,7 +30,7 @@ class GroupsController(BaseController):
             group_list = Group.index(repo_id)
         except HTTPInternalServerError:
             return abort(500)
-        group_list = [url.current(id=group, repo_id=repo_id) for group in group_list]
+        group_list = [url('group', id=group, repo_id=repo_id) for group in group_list]
         return json.dumps(group_list)
 
     def create(self, repo_id):
@@ -44,7 +44,7 @@ class GroupsController(BaseController):
             abort(409)
         except HTTPInternalServerError:
             abort(500)
-        response.headers['Location'] = url.current(id=group, repo_id=repo_id)
+        response.headers['Location'] = url('group', id=group, repo_id=repo_id)
         response.status_int = 201
 
     def new(self, format='html'):
