@@ -30,7 +30,7 @@ class ReposController(BaseController):
             repo_list = Repo.index()
         except HTTPInternalServerError:
             return abort(500)
-        repo_list = [url.current(id=repo) for repo in repo_list]
+        repo_list = [url('repo', id=repo) for repo in repo_list]
         return json.dumps(repo_list)
 
     def create(self):
@@ -44,7 +44,7 @@ class ReposController(BaseController):
             abort(409)
         except HTTPInternalServerError:
             abort(500)
-        response.headers['Location'] = url.current(id=repo)
+        response.headers['Location'] = url('repo', id=repo)
         response.status_int = 201
 
     def new(self, format='html'):
