@@ -37,7 +37,7 @@ class TestRulesController(TestController):
                                                     'member_list':['user1@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/rules/refex1,refex2;user1@test.com')))
+        self.assertEqual(_('/rules/refex1,refex2;user1@test.com'), response.headers['location'])
 
     # def test_new(self):
     #     response = self.app.get(url('new_rule'))
@@ -57,7 +57,7 @@ class TestRulesController(TestController):
                                                     'member_list':['user2@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/rules/refex3;user2@test.com')))
+        self.assertEqual(_('/rules/refex3;user2@test.com'), response.headers['location'])
         response = self.app.put(url('rule', id='refex3;user2@test.com', repo_id='repo1'),
                                  params=json.dumps({'permission':'RW+',
                                                     'refex_list':['refex3'],
@@ -80,7 +80,7 @@ class TestRulesController(TestController):
                                                     'member_list':['user2@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/rules/refex4;user2@test.com')))
+        self.assertEqual(_('/rules/refex4;user2@test.com'), response.headers['location'])
         response = self.app.delete(url('rule', id='refex4;user2@test.com', repo_id='repo1'))
         self.assertEqual(response.status, '200 OK')
         response = self.app.get(url('rules', repo_id='repo1'))
@@ -102,7 +102,7 @@ class TestRulesController(TestController):
                                                     'member_list':['user3@test.com']}),
                                  content_type='application/json')
         self.assertEqual(response.status, '201 Created')
-        self.assertTrue(response.headers['location'].endswith(_('/rules/refex5;user3@test.com')))
+        self.assertEqual(_('/rules/refex5;user3@test.com'), response.headers['location'])
         response = self.app.get(url('rule', id='refex5;user3@test.com', repo_id='repo1'))
         self.assertEqual(response.status, '200 OK')
         self.assertDictEqual(json.loads(response.body),
